@@ -25,8 +25,9 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,
     result$values <- round(eigens$values,digits)
     eigens$values[ eigens$values < .Machine$double.eps] <-  .Machine$double.eps  #added May 14, 2009 to fix case of singular matrices
     loadings <- eigens$vectors %*% sqrt(diag(eigens$values))
+   
    if(nfactors >0) {loadings <- loadings[,1:nfactors]} else {nfactors <- n}
-
+   if (nfactors>1) {communalities <- rowSums(loadings^2)} else {communalities <- loadings^2 }
    	
    
     	 
@@ -80,6 +81,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,
     result$loadings <- loadings
     result$Phi <- Phi
     result$Call <- cl
+    result$communality <- communalities
     if(scores) {result$scores <- factor.scores(scale(x.matrix),loadings) }
     return(result)
    }
